# Generated by Django 2.2.23 on 2021-06-28 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangocms_faq", "0002_auto_20210531_1650"),
    ]

    operations = [
        migrations.AlterField(
            model_name="searchfaqpluginmodel",
            name="search_in",
            field=models.ManyToManyField(
                limit_choices_to={"placeholder__page__publisher_is_draft": True},
                to="djangocms_faq.FaqPluginModel",
                verbose_name="Rechercher dans",
            ),
        ),
    ]
